# gm

Python GrayMeta API bindings.

This project is used to access your GrayMeta installation API using python.

## Installation

This is avaialble on pypy

    pip install gmapi

## Usage

	gm	
	


	


    
